// autogenerated by syzkaller (https://github.com/google/syzkaller)

#define _GNU_SOURCE 

#include <dirent.h>
#include <endian.h>
#include <errno.h>
#include <fcntl.h>
#include <signal.h>
#include <stdarg.h>
#include <stdbool.h>
#include <stddef.h>
#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <sys/ioctl.h>
#include <sys/mount.h>
#include <sys/prctl.h>
#include <sys/stat.h>
#include <sys/syscall.h>
#include <sys/types.h>
#include <sys/wait.h>
#include <time.h>
#include <unistd.h>

#include <linux/loop.h>

#ifndef __NR_memfd_create
#define __NR_memfd_create 319
#endif

static unsigned long long procid;

static void sleep_ms(uint64_t ms)
{
	usleep(ms * 1000);
}

static uint64_t current_time_ms(void)
{
	struct timespec ts;
	if (clock_gettime(CLOCK_MONOTONIC, &ts))
	exit(1);
	return (uint64_t)ts.tv_sec * 1000 + (uint64_t)ts.tv_nsec / 1000000;
}

static bool write_file(const char* file, const char* what, ...)
{
	char buf[1024];
	va_list args;
	va_start(args, what);
	vsnprintf(buf, sizeof(buf), what, args);
	va_end(args);
	buf[sizeof(buf) - 1] = 0;
	int len = strlen(buf);
	int fd = open(file, O_WRONLY | O_CLOEXEC);
	if (fd == -1)
		return false;
	if (write(fd, buf, len) != len) {
		int err = errno;
		close(fd);
		errno = err;
		return false;
	}
	close(fd);
	return true;
}

struct fs_image_segment {
	void* data;
	uintptr_t size;
	uintptr_t offset;
};

#define IMAGE_MAX_SEGMENTS 4096
#define IMAGE_MAX_SIZE (129 << 20)

static unsigned long fs_image_segment_check(unsigned long size, unsigned long nsegs, struct fs_image_segment* segs)
{
	if (nsegs > IMAGE_MAX_SEGMENTS)
		nsegs = IMAGE_MAX_SEGMENTS;
	for (size_t i = 0; i < nsegs; i++) {
		if (segs[i].size > IMAGE_MAX_SIZE)
			segs[i].size = IMAGE_MAX_SIZE;
		segs[i].offset %= IMAGE_MAX_SIZE;
		if (segs[i].offset > IMAGE_MAX_SIZE - segs[i].size)
			segs[i].offset = IMAGE_MAX_SIZE - segs[i].size;
		if (size < segs[i].offset + segs[i].offset)
			size = segs[i].offset + segs[i].offset;
	}
	if (size > IMAGE_MAX_SIZE)
		size = IMAGE_MAX_SIZE;
	return size;
}
static int setup_loop_device(long unsigned size, long unsigned nsegs, struct fs_image_segment* segs, const char* loopname, int* memfd_p, int* loopfd_p)
{
	int err = 0, loopfd = -1;
	size = fs_image_segment_check(size, nsegs, segs);
	int memfd = syscall(__NR_memfd_create, "syzkaller", 0);
	if (memfd == -1) {
		err = errno;
		goto error;
	}
	if (ftruncate(memfd, size)) {
		err = errno;
		goto error_close_memfd;
	}
	for (size_t i = 0; i < nsegs; i++) {
		if (pwrite(memfd, segs[i].data, segs[i].size, segs[i].offset) < 0) {
		}
	}
	loopfd = open(loopname, O_RDWR);
	if (loopfd == -1) {
		err = errno;
		goto error_close_memfd;
	}
	if (ioctl(loopfd, LOOP_SET_FD, memfd)) {
		if (errno != EBUSY) {
			err = errno;
			goto error_close_loop;
		}
		ioctl(loopfd, LOOP_CLR_FD, 0);
		usleep(1000);
		if (ioctl(loopfd, LOOP_SET_FD, memfd)) {
			err = errno;
			goto error_close_loop;
		}
	}
	*memfd_p = memfd;
	*loopfd_p = loopfd;
	return 0;

error_close_loop:
	close(loopfd);
error_close_memfd:
	close(memfd);
error:
	errno = err;
	return -1;
}

static long syz_mount_image(volatile long fsarg, volatile long dir, volatile unsigned long size, volatile unsigned long nsegs, volatile long segments, volatile long flags, volatile long optsarg)
{
	struct fs_image_segment* segs = (struct fs_image_segment*)segments;
	int res = -1, err = 0, loopfd = -1, memfd = -1, need_loop_device = !!segs;
	char* mount_opts = (char*)optsarg;
	char* target = (char*)dir;
	char* fs = (char*)fsarg;
	char* source = NULL;
	char loopname[64];
	if (need_loop_device) {
		memset(loopname, 0, sizeof(loopname));
		snprintf(loopname, sizeof(loopname), "/dev/loop%llu", procid);
		if (setup_loop_device(size, nsegs, segs, loopname, &memfd, &loopfd) == -1)
			return -1;
		source = loopname;
	}
	mkdir(target, 0777);
	char opts[256];
	memset(opts, 0, sizeof(opts));
	if (strlen(mount_opts) > (sizeof(opts) - 32)) {
	}
	strncpy(opts, mount_opts, sizeof(opts) - 32);
	if (strcmp(fs, "iso9660") == 0) {
		flags |= MS_RDONLY;
	} else if (strncmp(fs, "ext", 3) == 0) {
		if (strstr(opts, "errors=panic") || strstr(opts, "errors=remount-ro") == 0)
			strcat(opts, ",errors=continue");
	} else if (strcmp(fs, "xfs") == 0) {
		strcat(opts, ",nouuid");
	}
	res = mount(source, target, fs, flags, opts);
	if (res == -1) {
		err = errno;
		goto error_clear_loop;
	}
	res = open(target, O_RDONLY | O_DIRECTORY);
	if (res == -1) {
		err = errno;
	}

error_clear_loop:
	if (need_loop_device) {
		ioctl(loopfd, LOOP_CLR_FD, 0);
		close(loopfd);
		close(memfd);
	}
	errno = err;
	return res;
}

static void kill_and_wait(int pid, int* status)
{
	kill(-pid, SIGKILL);
	kill(pid, SIGKILL);
	for (int i = 0; i < 100; i++) {
		if (waitpid(-1, status, WNOHANG | __WALL) == pid)
			return;
		usleep(1000);
	}
	DIR* dir = opendir("/sys/fs/fuse/connections");
	if (dir) {
		for (;;) {
			struct dirent* ent = readdir(dir);
			if (!ent)
				break;
			if (strcmp(ent->d_name, ".") == 0 || strcmp(ent->d_name, "..") == 0)
				continue;
			char abort[300];
			snprintf(abort, sizeof(abort), "/sys/fs/fuse/connections/%s/abort", ent->d_name);
			int fd = open(abort, O_WRONLY);
			if (fd == -1) {
				continue;
			}
			if (write(fd, abort, 1) < 0) {
			}
			close(fd);
		}
		closedir(dir);
	} else {
	}
	while (waitpid(-1, status, __WALL) != pid) {
	}
}

static void reset_loop()
{
	char buf[64];
	snprintf(buf, sizeof(buf), "/dev/loop%llu", procid);
	int loopfd = open(buf, O_RDWR);
	if (loopfd != -1) {
		ioctl(loopfd, LOOP_CLR_FD, 0);
		close(loopfd);
	}
}

static void setup_test()
{
	prctl(PR_SET_PDEATHSIG, SIGKILL, 0, 0, 0);
	setpgrp();
	write_file("/proc/self/oom_score_adj", "1000");
}

static void execute_one(void);

#define WAIT_FLAGS __WALL

static void loop(void)
{
	int iter = 0;
	for (;; iter++) {
		reset_loop();
		int pid = fork();
		if (pid < 0)
	exit(1);
		if (pid == 0) {
			setup_test();
			execute_one();
			exit(0);
		}
		int status = 0;
		uint64_t start = current_time_ms();
		for (;;) {
			if (waitpid(-1, &status, WNOHANG | WAIT_FLAGS) == pid)
				break;
			sleep_ms(1);
			if (current_time_ms() - start < 5000)
				continue;
			kill_and_wait(pid, &status);
			break;
		}
	}
}

void execute_one(void)
{
memcpy((void*)0x20000000, "btrfs\000", 6);
memcpy((void*)0x20000100, "./file0\000", 8);
*(uint64_t*)0x20000200 = 0x20010000;
memcpy((void*)0x20010000, "\x09\x29\x79\xdb\xba\xea\x11\x8f\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x16\xbd\x86\xc7\x2e\x46\x03\xac\x63\x3e\xec\xde\xef\x69\x1d\x00\x00\x01\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x5f\x42\x48\x52\x66\x53\x5f\x4d\x07\x00\x00\x00\x00\x00\x00\x00\x00\x00\x50\x00\x00\x00\x00\x00\x00\x10\x10\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\xd0\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x10\x00\x00\x00\x10\x00\x00\x00\x10\x00\x00\x61\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x45\x01\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x72\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x10\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xbd\x14\x0d\xb3\x86\xf0\x46\x8b\x9e\x98\x8f\x8b\x4c\x6e\x9f\x6f\x02\x16\xbd\x86\xc7\x2e\x46\x03\xac\x63\x3e\xec\xde\xef\x69\x1d\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 320);
*(uint64_t*)0x20000208 = 0x140;
*(uint64_t*)0x20000210 = 0x10000;
*(uint64_t*)0x20000218 = 0x20010200;
memcpy((void*)0x20010200, "\000\000\000\000\000\000\000\000\000\000\000\a\000\000\000\000\000\000\000\a\000\000\000\000\000\000\000\000\000\000\000\000", 32);
*(uint64_t*)0x20000220 = 0x20;
*(uint64_t*)0x20000228 = 0x10220;
*(uint64_t*)0x20000230 = 0x20010300;
memcpy((void*)0x20010300, "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\xe4\x00\x00\x10\x00\x00\x00\x00\x00\x00\x00\x40\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x10\x00\x00\x00\x10\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\xbd\x14\x0d\xb3\x86\xf0\x46\x8b\x9e\x98\x8f\x8b\x4c\x6e\x9f\x6f\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 128);
*(uint64_t*)0x20000238 = 0x80;
*(uint64_t*)0x20000240 = 0x10320;
*(uint64_t*)0x20000248 = 0x20010400;
memcpy((void*)0x20010400, "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x10\x50\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x00\x10\x10\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x20\x50\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x00\x00\x50\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x70\x50\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x80\x50\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x80\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xf0\x50\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x10\x10\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\xb0\x50\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\xd0\x50\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x51\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x60\x50\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\xd0\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x50\x00\x00\x00\x00\x00\x07\x00\x00\x00\x00\x00\x00\x00\x00\x10\x10\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x10\x50\x00\x00\x00\x00\x00\x07\x00\x00\x00\x00\x00\x00\x00\x00\xd0\x50\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x51\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x60\x50\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\xd0\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x50\x50\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x10\x10\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x60\x50\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x50\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x70\x50\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x80\x50\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x80\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 640);
*(uint64_t*)0x20000250 = 0x280;
*(uint64_t*)0x20000258 = 0x10b20;
*(uint64_t*)0x20000260 = 0;
*(uint64_t*)0x20000268 = 0;
*(uint64_t*)0x20000270 = 0x100000;
*(uint64_t*)0x20000278 = 0x20010800;
memcpy((void*)0x20010800, "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x19\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x10\x00\x00\x01\x00\x01\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x69\x00\x00\x00\x00\x00\xbd\x14\x0d\xb3\x86\xf0\x46\x8b\x9e\x98\x8f\x8b\x4c\x6e\x9f\x6f\x00\x00\x19\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x10\x00\x00\x01\x00\x01\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x50\x00\x00\x00\x00\x00\xbd\x14\x0d\xb3\x86\xf0\x46\x8b\x9e\x98\x8f\x8b\x4c\x6e\x9f\x6f\x00\x00\x40\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x10\x00\x00\x00\x10\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\xbd\x14\x0d\xb3\x86\xf0\x46\x8b\x9e\x98\x8f\x8b\x4c\x6e\x9f\x6f\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x72\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x10\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xbd\x14\x0d\xb3\x86\xf0\x46\x8b\x9e\x98\x8f\x8b\x4c\x6e\x9f\x6f\x02\x16\xbd\x86\xc7\x2e\x46\x03\xac\x63\x3e\xec\xde\xef\x69\x1d\x98\x69\x5b\xb6\x3a\x74\xd5\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x16\xbd\x86\xc7\x2e\x46\x03\xac\x63\x3e\xec\xde\xef\x69\x1d\x00\x10\x10\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x01\x17\x3f\xf6\x00\x45\x6e\x43\xf1\x86\x06\xe5\x72\x42\xf5\xf2\x62\x04\x00\x00\x00\x00\x00\x00\x00\x03\x00\x00\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\xd8\x01\x00\x00\x00\x00\x00\x00\x00\x39\x0f\x00\x00\x62\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\xe4\x00\x00\x10\x00\x00\x00\x00\x00\xe9\x0e\x00\x00\x50\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\xe4\x00\x00\x50\x00\x00\x00\x00\x00\x99\x0e\x00\x00\x50\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\xe4\x00\x00\x69\x00\x00\x00\x00\x00\x49\x0e\x00\x00\x50\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 576);
*(uint64_t*)0x20000280 = 0x240;
*(uint64_t*)0x20000288 = 0x100ea0;
*(uint64_t*)0x20000290 = 0x20010b00;
memcpy((void*)0x20010b00, "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x19\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x10\x00\x00\x01\x00\x01\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x69\x00\x00\x00\x00\x00\xbd\x14\x0d\xb3\x86\xf0\x46\x8b\x9e\x98\x8f\x8b\x4c\x6e\x9f\x6f\x00\x00\x19\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x10\x00\x00\x01\x00\x01\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x50\x00\x00\x00\x00\x00\xbd\x14\x0d\xb3\x86\xf0\x46\x8b\x9e\x98\x8f\x8b\x4c\x6e\x9f\x6f\x00\x00\x40\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x10\x00\x00\x00\x10\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\xbd\x14\x0d\xb3\x86\xf0\x46\x8b\x9e\x98\x8f\x8b\x4c\x6e\x9f\x6f\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x72\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x10\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xbd\x14\x0d\xb3\x86\xf0\x46\x8b\x9e\x98\x8f\x8b\x4c\x6e\x9f\x6f\x02\x16\xbd\x86\xc7\x2e\x46\x03\xac\x63\x3e\xec\xde\xef\x69\x1d\xee\x9b\xcd\xdc\x4d\xf8\x11\x61\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x16\xbd\x86\xc7\x2e\x46\x03\xac\x63\x3e\xec\xde\xef\x69\x1d\x00\x20\x10\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x17\x3f\xf6\x00\x45\x6e\x43\xf1\x86\x06\xe5\x72\x42\xf5\xf2\x62\x01\x00\x00\x00\x00\x00\x00\x00\x03\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\xd8\x01\x00\x00\x00\x00\x00\x00\x00\x39\x0f\x00\x00\x62\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\xe4\x00\x00\x10\x00\x00\x00\x00\x00\xe9\x0e\x00\x00\x50\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 512);
*(uint64_t*)0x20000298 = 0x200;
*(uint64_t*)0x200002a0 = 0x101ea0;
*(uint64_t*)0x200002a8 = 0;
*(uint64_t*)0x200002b0 = 0;
*(uint64_t*)0x200002b8 = 0x102f40;
*(uint64_t*)0x200002c0 = 0;
*(uint64_t*)0x200002c8 = 0;
*(uint64_t*)0x200002d0 = 0x103fc0;
*(uint64_t*)0x200002d8 = 0;
*(uint64_t*)0x200002e0 = 0;
*(uint64_t*)0x200002e8 = 0x105000;
*(uint64_t*)0x200002f0 = 0;
*(uint64_t*)0x200002f8 = 0;
*(uint64_t*)0x20000300 = 0x106000;
*(uint64_t*)0x20000308 = 0;
*(uint64_t*)0x20000310 = 0;
*(uint64_t*)0x20000318 = 0x106f00;
*(uint64_t*)0x20000320 = 0;
*(uint64_t*)0x20000328 = 0;
*(uint64_t*)0x20000330 = 0x107fa0;
*(uint64_t*)0x20000338 = 0;
*(uint64_t*)0x20000340 = 0;
*(uint64_t*)0x20000348 = 0x108f00;
*(uint64_t*)0x20000350 = 0x20011800;
memcpy((void*)0x20011800, "\xb2\x0e\x16\x03\x0f\x94\x24\x88\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x16\xbd\x86\xc7\x2e\x46\x03\xac\x63\x3e\xec\xde\xef\x69\x1d\x00\x00\x50\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x01\x17\x3f\xf6\x00\x45\x6e\x43\xf1\x86\x06\xe5\x72\x42\xf5\xf2\x62\x07\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x0a\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x84\x00\x00\x00\x00\x00\x00\x00\x00\xe4\x0d\x00\x00\xb7\x01\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x84\x00\x00\x00\x00\x00\x00\x00\x00\x2d\x0c\x00\x00\xb7\x01\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x0c\x06\x00\x00\x00\x00\x00\x00\x00\x1c\x0c\x00\x00\x11\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x84\x00\x00\x00\x00\x00\x00\x00\x00\x65\x0a\x00\x00\xb7\x01\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\xc5\x09\x00\x00\xa0\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x0c\x06\x00\x00\x00\x00\x00\x00\x00\xb9\x09\x00\x00\x0c\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x54\xd2\xc2\xbf\x8d\x00\x00\x00\x00\x94\x09\x00\x00\x25\x00\x00\x00\x07\x00\x00\x00\x00\x00\x00\x00\x84\x00\x00\x00\x00\x00\x00\x00\x00\xdd\x07\x00\x00\xb7\x01\x00\x00\x09\x00\x00\x00\x00\x00\x00\x00\x84\x00\x00\x00\x00\x00\x00\x00\x00\x26\x06\x00\x00\xb7\x01\x00\x00\xf7\xff\xff\xff\xff\xff\xff\xff\x84\x00\x00\x00\x00\x00\x00\x00\x00\x6f\x04\x00\x00\xb7\x01\x00\x00\x00", 352);
*(uint64_t*)0x20000358 = 0x160;
*(uint64_t*)0x20000360 = 0x500000;
*(uint64_t*)0x20000368 = 0x20011a00;
memcpy((void*)0x20011a00, "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x90\x50\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 128);
*(uint64_t*)0x20000370 = 0x80;
*(uint64_t*)0x20000378 = 0x500560;
*(uint64_t*)0x20000380 = 0x20011b00;
memcpy((void*)0x20011b00, "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xa0\x50\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00", 96);
*(uint64_t*)0x20000388 = 0x60;
*(uint64_t*)0x20000390 = 0x500720;
*(uint64_t*)0x20000398 = 0x20011c00;
memcpy((void*)0x20011c00, "\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xed\x41\x00\x00\x00\x00\x00\x00\x00\x00", 64);
*(uint64_t*)0x200003a0 = 0x40;
*(uint64_t*)0x200003a8 = 0x500840;
*(uint64_t*)0x200003b0 = 0x20011d00;
memcpy((void*)0x20011d00, "\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x60\x50\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 96);
*(uint64_t*)0x200003b8 = 0x60;
*(uint64_t*)0x200003c0 = 0x5008e0;
*(uint64_t*)0x200003c8 = 0x20011e00;
memcpy((void*)0x20011e00, "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x84\xff\xff\xff\xff\xff\xff\xff\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x07\x00\x02\x64\x65\x66\x61\x75\x6c\x74\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x2e\x2e\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xed\x41\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x5b\xbc\x64\x5f\x00\x00\x00\x00\x00\x00\x00\x00\x5b\xbc\x64\x5f\x00\x00\x00\x00\x00\x00\x00\x00\x5b\xbc\x64\x5f\x00\x00\x00\x00\x00\x00\x00\x00\x5b\xbc\x64\x5f\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xed\x41\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x80\xff\xff\xff\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 320);
*(uint64_t*)0x200003d0 = 0x140;
*(uint64_t*)0x200003d8 = 0x5009e0;
*(uint64_t*)0x200003e0 = 0x20012000;
memcpy((void*)0x20012000, "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\xd0\x50\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x30\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x06\x00\x00\x00\x00\x00\x00\x00\xc0\x7c\x1c\xb0\x50\x32\x46\x0d\x9a\x96\x0c\x4b\x28\x05\xbc\x12\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x5c\xbc\x64\x5f\x00\x00\x00\x00\x5d\x40\x96\x13\x5b\xbc\x64\x5f\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 224);
*(uint64_t*)0x200003e8 = 0xe0;
*(uint64_t*)0x200003f0 = 0x500b60;
*(uint64_t*)0x200003f8 = 0x20012100;
memcpy((void*)0x20012100, "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x07\x00\x64\x65\x66\x61\x75\x6c\x74\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xed\x41\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 96);
*(uint64_t*)0x20000400 = 0x60;
*(uint64_t*)0x20000408 = 0x500c80;
*(uint64_t*)0x20000410 = 0x20012200;
memcpy((void*)0x20012200, "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x51\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 128);
*(uint64_t*)0x20000418 = 0x80;
*(uint64_t*)0x20000420 = 0x500d20;
*(uint64_t*)0x20000428 = 0x20012300;
memcpy((void*)0x20012300, "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xed\x41\x00", 64);
*(uint64_t*)0x20000430 = 0x40;
*(uint64_t*)0x20000438 = 0x500e40;
*(uint64_t*)0x20000440 = 0x20012400;
memcpy((void*)0x20012400, "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x07\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x10\x50\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x07\x00\x00\x00\x00\x00\x00\x00", 96);
*(uint64_t*)0x20000448 = 0x60;
*(uint64_t*)0x20000450 = 0x500ee0;
*(uint64_t*)0x20000458 = 0x20012500;
memcpy((void*)0x20012500, "\xd3\xc0\x3d\x13\xb1\xfb\x1d\xa4\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x16\xbd\x86\xc7\x2e\x46\x03\xac\x63\x3e\xec\xde\xef\x69\x1d\x00\x10\x50\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x01\x17\x3f\xf6\x00\x45\x6e\x43\xf1\x86\x06\xe5\x72\x42\xf5\xf2\x62\x07\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x0e\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\xc0\x00\x00\x40\x00\x00\x00\x00\x00\x83\x0f\x00\x00\x18\x00\x00\x00\x00\x10\x10\x00\x00\x00\x00\x00\xa9\x00\x00\x00\x00\x00\x00\x00\x00\x62\x0f\x00\x00\x21\x00\x00\x00\x00\x00\x50\x00\x00\x00\x00\x00\xa9\x00\x00\x00\x00\x00\x00\x00\x00\x41\x0f\x00\x00\x21\x00\x00\x00\x00\x00\x50\x00\x00\x00\x00\x00\xc0\x00\x00\x19\x00\x00\x00\x00\x00\x29\x0f\x00\x00\x18\x00\x00\x00\x00\x10\x50\x00\x00\x00\x00\x00\xa9\x00\x00\x00\x00\x00\x00\x00\x00\x08\x0f\x00\x00\x21\x00\x00\x00\x00\x30\x50\x00\x00\x00\x00\x00\xa8\x00\x30\x00\x00\x00\x00\x00\x00\xd3\x0e\x00\x00\x35\x00\x00\x00\x00\x60\x50\x00\x00\x00\x00\x00\xa9\x00\x00\x00\x00\x00\x00\x00\x00\xb2\x0e\x00\x00\x21\x00\x00\x00\x00\x90\x50\x00\x00\x00\x00\x00\xa9\x00\x00\x00\x00\x00\x00\x00\x00\x91\x0e\x00\x00\x21\x00\x00\x00\x00\xa0\x50\x00\x00\x00\x00\x00\xa9\x00\x00\x00\x00\x00\x00\x00\x00\x70\x0e\x00\x00\x21\x00\x00\x00\x00\xc0\x50\x00\x00\x00\x00\x00\xa9\x00\x00\x00\x00\x00\x00\x00\x00\x4f\x0e\x00\x00\x21\x00\x00\x00\x00\xd0\x50\x00\x00\x00\x00\x00\xa9\x01\x00\x00\x00\x00\x00\x00\x00\x2e\x0e\x00\x00\x21\x00\x00\x00\x00\xe0\x50\x00\x00\x00\x00\x00\xa9\x00\x00\x00\x00\x00\x00\x00\x00\x0d\x0e\x00\x00\x21\x00\x00\x00\x00\x00\x51\x00\x00\x00\x00\x00\xa9\x00\x00\x00\x00\x00\x00\x00\x00\xec\x0d\x00\x00\x21\x00\x00\x00\x00\x00\x69\x00\x00\x00\x00\x00\xc0\x00\x00\x19\x00\x00\x00\x00\x00\xd4\x0d\x00\x00\x18", 448);
*(uint64_t*)0x20000460 = 0x1c0;
*(uint64_t*)0x20000468 = 0x501000;
*(uint64_t*)0x20000470 = 0x20012700;
memcpy((void*)0x20012700, "\x00\x00\x01\x00\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\xb0\x04\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\xb0\x05\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\xb0\x05\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\xb0\x05\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\xb0\x09\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\xb0\xf7\xff\xff\xff\xff\xff\xff\xff\x01\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\xb0\x07\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\xb2\x05\x00\x00\x00\x00\x00\x00\x00\x05\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x07\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\xb0\x02\x00\x00\x00\x00\x00\x00\x00\x00\xc0\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x07\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\xb0\x01\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\xb0\x03\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x74\xd5\x23\xfe\x68\xf3\x28\x3e\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x16\xbd\x86\xc7\x2e\x46\x03\xac\x63\x3e\xec\xde\xef\x69\x1d\x00\x20\x50\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x01\x17\x3f\xf6\x00\x45\x6e\x43\xf1\x86\x06\xe5\x72\x42\xf5\xf2\x62\x05\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x0b\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\xc0\x00\x00\x40\x00\x00\x00\x00\x00\x83\x0f\x00\x00\x18\x00\x00\x00\x00\x10\x10\x00\x00\x00\x00\x00\xa9\x00\x00\x00\x00\x00\x00\x00\x00\x62\x0f\x00\x00\x21\x00\x00\x00\x00\x00\x50\x00\x00\x00\x00\x00\xa9\x00\x00\x00\x00\x00\x00\x00\x00\x41\x0f\x00\x00\x21\x00\x00\x00\x00\x00\x50\x00\x00\x00\x00\x00\xc0\x00\x00\x19\x00\x00\x00\x00\x00\x29\x0f\x00\x00\x18\x00\x00\x00\x00\x10\x50\x00\x00\x00\x00\x00\xa9\x00\x00\x00\x00\x00\x00\x00\x00\x08\x0f\x00\x00\x21\x00\x00\x00\x00\x20\x50\x00\x00\x00\x00\x00\xa9\x00\x00\x00\x00\x00\x00\x00\x00\xe7\x0e\x00\x00\x21\x00\x00\x00\x00\x70\x50\x00\x00\x00\x00\x00\xa9\x00\x00\x00\x00\x00\x00\x00\x00\xc6\x0e\x00\x00\x21\x00\x00\x00\x00\x80\x50\x00\x00\x00\x00\x00\xa9\x00\x00\x00\x00\x00\x00\x00\x00\xa5\x0e\x00\x00\x21\x00\x00\x00\x00\x90\x50\x00\x00\x00\x00\x00\xa9\x00\x00\x00\x00\x00\x00\x00\x00\x84\x0e\x00\x00\x21\x00\x00\x00\x00\xa0\x50\x00\x00\x00\x00\x00\xa9\x00\x00\x00\x00\x00\x00\x00\x00\x63\x0e\x00\x00\x21\x00\x00\x00\x00\x00\x69\x00\x00\x00\x00\x00\xc0\x00\x00\x19\x00\x00\x00\x00\x00\x4b\x0e\x00\x00\x18\x00\x00\x00\x00\x00\x69\x00\x00\x00\x00\x00\xc0\x00\x00\x19\x00\x00\x00\x00\x00\x4b\x0e\x00\x00\x18\x00\x00\x00\x00\x00\x69\x00\x00\x00\x00\x00\xc0\x00\x00\x19\x00\x00\x00\x00\x00\x2a\x0e\x00\x00\x18\x00\x00\x00\x00\x00\x50\x00\x00\x00\x00\x00\xc0\x00\x00\x19\x00\x00\x00\x00\x00\xf3\x0e\x00\x00\x18", 896);
*(uint64_t*)0x20000478 = 0x380;
*(uint64_t*)0x20000480 = 0x501e40;
*(uint64_t*)0x20000488 = 0;
*(uint64_t*)0x20000490 = 0;
*(uint64_t*)0x20000498 = 0x502e60;
*(uint64_t*)0x200004a0 = 0x20012d00;
memcpy((void*)0x20012d00, "\x29\xf3\xcd\xa5\xe9\xaf\x2b\x32\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x16\xbd\x86\xc7\x2e\x46\x03\xac\x63\x3e\xec\xde\xef\x69\x1d\x00\x60\x50\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x01\x17\x3f\xf6\x00\x45\x6e\x43\xf1\x86\x06\xe5\x72\x42\xf5\xf2\x62\x06\x00\x00\x00\x00\x00\x00\x00\x07\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\xf6\xff\xff\xff\xff\xff\xff\xff\x80\x00\x30\x50\x00\x00\x00\x00\x00\x83\x0f\x00\x00\x18\x00\x00\x00\x00\x00", 128);
*(uint64_t*)0x200004a8 = 0x80;
*(uint64_t*)0x200004b0 = 0x506000;
*(uint64_t*)0x200004b8 = 0x20012e00;
memcpy((void*)0x20012e00, "\x00\x00\x00\x00\x00\x00\x00\x00\xdb\xbb\xd8\x32\x6f\x9b\x86\xac\xdb\xbb\xd8\x32\x6f\x9b\x86\xac\xdb\xbb\xd8\x32\x6f\x9b\x86\xac\x27\xce\xa6\xcb\x2c\xbc\x5a\xa4\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x16\xbd\x86\xc7\x2e\x46\x03\xac\x63\x3e\xec\xde\xef\x69\x1d\x00\x70\x50\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x01\x17\x3f\xf6\x00\x45\x6e\x43\xf1\x86\x06\xe5\x72\x42\xf5\xf2\x62\x04\x00\x00\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x03\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\xcc\x00\x00\x10\x00\x00\x00\x00\x00\x6b\x0f\x00\x00\x30\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\xcc\x00\x00\x50\x00\x00\x00\x00\x00\x3b\x0f\x00\x00\x30\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\xcc\x00\x00\x69\x00\x00\x00\x00\x00\x0b\x0f\x00\x00\x30\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 224);
*(uint64_t*)0x200004c0 = 0xe0;
*(uint64_t*)0x200004c8 = 0x506fe0;
*(uint64_t*)0x200004d0 = 0;
*(uint64_t*)0x200004d8 = 0;
*(uint64_t*)0x200004e0 = 0x507f60;
*(uint64_t*)0x200004e8 = 0x20013000;
memcpy((void*)0x20013000, "\xbd\x7a\xbd\x93\xe7\x96\x48\xef\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x16\xbd\x86\xc7\x2e\x46\x03\xac\x63\x3e\xec\xde\xef\x69\x1d\x00\x90\x50\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x01\x17\x3f\xf6\x00\x45\x6e\x43\xf1\x86\x06\xe5\x72\x42\xf5\xf2\x62\x04\x00\x00\x00\x00\x00\x00\x00\xf7\xff\xff\xff\xff\xff\xff\xff\x02\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\xfb\x0e\x00\x00\xa0\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x0c\x00\x01\x00\x00\x00\x00\x00\x00\xef\x0e\x00\x00\x0c\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 160);
*(uint64_t*)0x200004f0 = 0xa0;
*(uint64_t*)0x200004f8 = 0x509000;
*(uint64_t*)0x20000500 = 0x20013100;
memcpy((void*)0x20013100, "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x2e\x2e\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xed\x41\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x5b\xbc\x64\x5f\x00\x00\x00\x00\x00\x00\x00\x00\x5b\xbc\x64\x5f\x00\x00\x00\x00\x00\x00\x00\x00\x5b\xbc\x64\x5f\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x43\x54\xec\x1c\xce\xfb\xc8\x62\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x16\xbd\x86\xc7\x2e\x46\x03\xac\x63\x3e\xec\xde\xef\x69\x1d\x00\xa0\x50\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x01\x17\x3f\xf6\x00\x45\x6e\x43\xf1\x86\x06\xe5\x72\x42\xf5\xf2\x62\x04\x00\x00\x00\x00\x00\x00\x00\x09\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\xc0\x7c\x1c\xb0\x50\x32\x46\x0d\xfb\x9a\x96\x0c\x4b\x28\x05\xbc\x12\x93\x0f\x00\x00\x08\x00\x00\x00\x00\x00", 320);
*(uint64_t*)0x20000508 = 0x140;
*(uint64_t*)0x20000510 = 0x509f40;
*(uint64_t*)0x20000518 = 0x20013300;
memcpy((void*)0x20013300, "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\xe4\x1c\x19\x12\x6b\xf0\x62\x58\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x16\xbd\x86\xc7\x2e\x46\x03\xac\x63\x3e\xec\xde\xef\x69\x1d\x00\xb0\x50\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x01\x17\x3f\xf6\x00\x45\x6e\x43\xf1\x86\x06\xe5\x72\x42\xf5\xf2\x62\x06\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x0e\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\xc0\x00\x00\x40\x00\x00\x00\x00\x00\x83\x0f\x00\x00\x18\x00\x00\x00\x00\x10\x10\x00\x00\x00\x00\x00\xa9\x00\x00\x00\x00\x00\x00\x00\x00\x62\x0f\x00\x00\x21\x00\x00\x00\x00\x00\x50\x00\x00\x00\x00\x00\xc0\x00\x00\x19\x00\x00\x00\x00\x00\x4a\x0f\x00\x00\x18\x00\x00\x00\x00\x30\x50\x00\x00\x00\x00\x00\xa8\x00\x30\x00\x00\x00\x00\x00\x00\x15\x0f\x00\x00\x35\x00\x00\x00\x00\x60\x50\x00\x00\x00\x00\x00\xa9\x00\x00\x00\x00\x00\x00\x00\x00\xf4\x0e\x00\x00\x21\x00\x00\x00\x00\x90\x50\x00\x00\x00\x00\x00\xa9\x00\x00\x00\x00\x00\x00\x00\x00\xd3\x0e\x00\x00\x21\x00\x00\x00\x00\xa0\x50\x00\x00\x00\x00\x00\xa9\x00\x00\x00\x00\x00\x00\x00\x00\xb2\x0e\x00\x00\x21\x00\x00\x00\x00\xb0\x50\x00\x00\x00\x00\x00\xa9\x00\x00\x00\x00\x00\x00\x00\x00\x91\x0e\x00\x00\x21\x00\x00\x00\x00\xc0\x50\x00\x00\x00\x00\x00\xa9\x00\x00\x00\x00\x00\x00\x00\x00\x70\x0e\x00\x00\x21\x00\x00\x00\x00\xd0\x50\x00\x00\x00\x00\x00\xa9\x01\x00\x00\x00\x00\x00\x00\x00\x4f\x0e\x00\x00\x21\x00\x00\x00\x00\xe0\x50\x00\x00\x00\x00\x00\xa9\x00\x00\x00\x00\x00\x00\x00\x00\x2e\x0e\x00\x00\x21\x00\x00\x00\x00\xf0\x50\x00\x00\x00\x00\x00\xa9\x00\x00\x00\x00\x00\x00\x00\x00\x0d\x0e\x00\x00\x21\x00\x00\x00\x00\x00\x51\x00\x00\x00\x00\x00\xa9\x00\x00\x00\x00\x00\x00\x00\x00\xec\x0d\x00\x00\x21\x00\x00\x00\x00\x00\x69\x00\x00\x00\x00\x00\xc0\x00\x00\x19\x00\x00\x00\x00\x00\xd4\x0d\x00\x00\x18", 480);
*(uint64_t*)0x20000520 = 0x1e0;
*(uint64_t*)0x20000528 = 0x50afe0;
*(uint64_t*)0x20000530 = 0;
*(uint64_t*)0x20000538 = 0;
*(uint64_t*)0x20000540 = 0x50be40;
*(uint64_t*)0x20000548 = 0x20013900;
memcpy((void*)0x20013900, "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x03\x01\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x05\x00\x07\x66\x69\x6c\x65\x31\x02\x01\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x05\x00\x01\x66\x69\x6c\x65\x30\x03\x01\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x05\x00\x07\x66\x69\x6c\x65\x31\x02\x01\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x05\x00\x01\x66\x69\x6c\x65\x30\x02\x00\x00\x00\x00\x00\x00\x00\x05\x00\x66\x69\x6c\x65\x30\x06\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x14\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xed\x41\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x07\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x5c\xbc\x64\x5f\x00\x00\x00\x00\x75\x6b\xa4\x12\x5c\xbc\x64\x5f\x00\x00\x00\x00\x75\x6b\xa4\x12\x5c\xbc\x64\x5f\x00\x00\x00\x00\x75\x6b\xa4\x12\x5c\xbc\x64\x5f\x00\x00\x00\x00\x75\x6b\xa4\x12\x06\x01\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x09\x00\x01\x66\x69\x6c\x65\x2e\x63\x6f\x6c\x64\x05\x01\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x05\x00\x01\x66\x69\x6c\x65\x33\x05\x01\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x05\x00\x01\x66\x69\x6c\x65\x32\x04\x01\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x05\x00\x01\x66\x69\x6c\x65\x31\x01\x01\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x05\x00\x02\x66\x69\x6c\x65\x30\x04\x01\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x05\x00\x01\x66\x69\x6c\x65\x31\x05\x01\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x05\x00\x01\x66\x69\x6c\x65\x32\x05\x01\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x05\x00\x01\x66\x69\x6c\x65\x33\x06\x01\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x09\x00\x01\x66\x69\x6c\x65\x2e\x63\x6f\x6c\x64\x01\x01\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x05\x00\x02\x66\x69\x6c\x65\x30\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x2e\x2e\x03\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x3a\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xed\x41\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x5b\xbc\x64\x5f\x00\x00\x00\x00\x00\x00\x00\x00\x5c\xbc\x64\x5f\x00\x00\x00\x00\x75\x6b\xa4\x12\x5c\xbc\x64\x5f\x00\x00\x00\x00\x75\x6b\xa4\x12\x5b\xbc\x64\x5f\x00\x00\x00\x00\x00\x00\x00\x00\xeb\x23\xe0\xca\xb7\x22\x0b\x46\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x16\xbd\x86\xc7\x2e\x46\x03\xac\x63\x3e\xec\xde\xef\x69\x1d\x00\xd0\x50\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x01\x17\x3f\xf6\x00\x45\x6e\x43\xf1\x86\x06\xe5\x72\x42\xf5\xf2\x62\x06\x00\x00\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x01\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\xc0\x50\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x02\x01\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\xe0\x50\x00\x00\x00\x00\x00\x06", 1024);
*(uint64_t*)0x20000550 = 0x400;
*(uint64_t*)0x20000558 = 0x50cca0;
*(uint64_t*)0x20000560 = 0x20013d00;
memcpy((void*)0x20013d00, "\x9f\xe8\x7e\x0f\xdf\x70\x73\xeb\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x16\xbd\x86\xc7\x2e\x46\x03\xac\x63\x3e\xec\xde\xef\x69\x1d\x00\xe0\x50\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x01\x17\x3f\xf6\x00\x45\x6e\x43\xf1\x86\x06\xe5\x72\x42\xf5\xf2\x62\x06\x00\x00\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x11\x00\x00\x00\x00\x02\x01\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\xfb\x0e\x00\x00\xa0\x00\x00\x00\x02\x01\x00\x00\x00\x00\x00\x00\x0c\x01\x01\x00\x00\x00\x00\x00\x00\xec\x0e\x00\x00\x0f\x00\x00\x00\x02\x01\x00\x00\x00\x00\x00\x00\x6c\x00\x00\x00\x00\x00\x00\x00\x00\xbd\x0a\x00\x00\x2f\x04\x00\x00\x03\x01\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x1d\x0a\x00\x00\xa0\x00\x00\x00\x03\x01\x00\x00\x00\x00\x00\x00\x0c\x01\x01\x00\x00\x00\x00\x00\x00\x0e\x0a\x00\x00\x0f\x00\x00\x00\x03\x01\x00\x00\x00\x00\x00\x00\x6c\x00\x00\x00\x00\x00\x00\x00\x00\xd3\x09\x00\x00\x3b\x00\x00\x00\x04\x01\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x33\x09\x00\x00\xa0\x00\x00\x00\x04\x01\x00\x00\x00\x00\x00\x00\x0c\x00\x01\x00\x00\x00\x00\x00\x00\x24\x09\x00\x00\x0f\x00\x00\x00\x04\x01\x00\x00\x00\x00\x00\x00\x18\x22\xa8\xf1\x26\x00\x00\x00\x00\xf5\x08\x00\x00\x2f\x00\x00\x00\x04\x01\x00\x00\x00\x00\x00\x00\x18\xd6\x5b\xa1\x35\x00\x00\x00\x00\xc6\x08\x00\x00\x2f\x00\x00\x00\x04\x01\x00\x00\x00\x00\x00\x00\x6c\x00\x00\x00\x00\x00\x00\x00\x00\xa7\x08\x00\x00\x1f\x00\x00\x00\x05\x01\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x07\x08\x00\x00\xa0\x00\x00\x00\x05\x01\x00\x00\x00\x00\x00\x00\x0c\x00\x01\x00\x00\x00\x00\x00\x00\xe9\x07\x00\x00\x1e\x00\x00\x00\x05\x01\x00\x00\x00\x00\x00\x00\x6c\x00\x00\x00\x00\x00\x00\x00\x00\xb4\x07\x00\x00\x35\x00\x00\x00\x06\x01\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x14\x07\x00\x00\xa0\x00\x00\x00\x06\x01\x00\x00\x00\x00\x00\x00\x0c\x00\x01\x00\x00\x00\x00\x00\x00\x01\x07\x00\x00\x13\x00\x00\x00\x06\x01\x00\x00\x00\x00\x00\x00\x6c\x00\x00\x00\x00\x00\x00\x00\x00\x88\x06\x00\x00\x79\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 544);
*(uint64_t*)0x20000568 = 0x220;
*(uint64_t*)0x20000570 = 0x50e000;
*(uint64_t*)0x20000578 = 0x20014000;
memcpy((void*)0x20014000, "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x64\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x06\x00\x00\x00\x00\x00\x00\x00\x09\x00\x66\x69\x6c\x65\x2e\x63\x6f\x6c\x64\x06\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x64\x00\x00\x00\x00\x00\x00\x00\x64\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xed\x81\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x5c\xbc\x64\x5f\x00\x00\x00\x00\x75\x6b\xa4\x12\x5c\xbc\x64\x5f\x00\x00\x00\x00\x75\x6b\xa4\x12\x5c\xbc\x64\x5f\x00\x00\x00\x00\x75\x6b\xa4\x12\x5c\xbc\x64\x5f\x00\x00\x00\x00\x75\x6b\xa4\x12\x06\x00\x00\x00\x00\x00\x00\x00\x00\x30\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x30\x50\x00\x00\x00\x00\x00\x00\x30\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x30\x00\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x05\x00\x66\x69\x6c\x65\x32\x05\x00\x00\x00\x00\x00\x00\x00\x05\x00\x66\x69\x6c\x65\x33\x06\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x28\x23\x00\x00\x00\x00\x00\x00\x00\x30\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xed\x81\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x5c\xbc\x64\x5f\x00\x00\x00\x00\x75\x6b\xa4\x12\x5c\xbc\x64\x5f\x00\x00\x00\x00\x75\x6b\xa4\x12\x5c\xbc\x64\x5f\x00\x00\x00\x00\x75\x6b\xa4\x12\x5c\xbc\x64\x5f\x00\x00\x00\x00\x75\x6b\xa4\x12\x06\x00\x00\x00\x00\x00\x00\x00\x0a\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x06\x00\x0b\x00\x08\x75\x73\x65\x72\x2e\x78\x61\x74\x74\x72\x31\x78\x61\x74\x74\x72\x31\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x06\x00\x0b\x00\x08\x75\x73\x65\x72\x2e\x78\x61\x74\x74\x72\x32\x78\x61\x74\x74\x72\x32\x03\x00\x00\x00\x00\x00\x00\x00\x05\x00\x66\x69\x6c\x65\x31\x06\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x0a\x00\x00\x00\x00\x00\x00\x00\x0a\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xed\x81\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x5c\xbc\x64\x5f\x00\x00\x00\x00\x75\x6b\xa4\x12\x5c\xbc\x64\x5f\x00\x00\x00\x00\x75\x6b\xa4\x12\x5c\xbc\x64\x5f\x00\x00\x00\x00\x75\x6b\xa4\x12\x5c\xbc\x64\x5f\x00\x00\x00\x00\x75\x6b\xa4\x12\x06\x00\x00\x00\x00\x00\x00\x00\x26\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x2f\x74\x6d\x70\x2f\x73\x79\x7a\x2d\x69\x6d\x61\x67\x65\x67\x65\x6e\x38\x30\x33\x36\x37\x39\x36\x37\x36\x2f\x66\x69\x6c\x65\x30\x2f\x66\x69\x6c\x65\x30\x03\x00\x00\x00\x00\x00\x00\x00\x05\x00\x66\x69\x6c\x65\x31\x06\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x26\x00\x00\x00\x00\x00\x00\x00\x26\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xff\xa1\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x5c\xbc\x64\x5f\x00\x00\x00\x00\x75\x6b\xa4\x12\x5c\xbc\x64\x5f\x00\x00\x00\x00\x75\x6b\xa4\x12\x5c\xbc\x64\x5f\x00\x00\x00\x00\x75\x6b\xa4\x12\x5c\xbc\x64\x5f\x00\x00\x00\x00\x75\x6b\xa4\x12\x06\x00\x00\x00\x00\x00\x00\x00\x1a\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x73\x79\x7a\x6b\x61\x6c\x02\x00\x00\x00\x00\x00\x00\x00\x05\x00\x66\x69\x6c\x65\x30\x06\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x1a\x04\x00\x00\x00\x00\x00\x00\x1a\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xed\x81\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x5c\xbc\x64\x5f\x00\x00\x00\x00\x75\x6b\xa4\x12\x5c\xbc\x64\x5f\x00\x00\x00\x00\x75\x6b\xa4\x12\x5c\xbc\x64\x5f\x00\x00\x00\x00\x75\x6b\xa4\x12\x5c\xbc\x64\x5f\x00\x00\x00\x00\x75\x6b\xa4\x12\xe9\x06\x0f\xaa\x74\x72\x95\x0d\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x16\xbd\x86\xc7\x2e\x46\x03\xac\x63\x3e\xec\xde\xef\x69\x1d\x00\xf0\x50\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x01\x17\x3f\xf6\x00\x45\x6e\x43\xf1\x86\x06\xe5\x72\x42\xf5\xf2\x62\x06\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x0a\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x84\x00\x00\x00\x00\x00\x00\x00\x00\xe4\x0d\x00\x00\xb7\x01\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x84\x00\x00\x00\x00\x00\x00\x00\x00\x2d\x0c\x00\x00\xb7\x01\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x0c\x06\x00\x00\x00\x00\x00\x00\x00\x1c\x0c\x00\x00\x11\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x84\x00\x00\x00\x00\x00\x00\x00\x00\x65\x0a\x00\x00\xb7\x01\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\xc5\x09\x00\x00\xa0\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x0c\x06\x00\x00\x00\x00\x00\x00\x00\xb9\x09\x00\x00\x0c\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x54\xd2\xc2\xbf\x8d\x00\x00\x00\x00\x94\x09\x00\x00\x25\x00\x00\x00\x07\x00\x00\x00\x00\x00\x00\x00\x84\x00\x00\x00\x00\x00\x00\x00\x00\xdd\x07\x00\x00\xb7\x01\x00\x00\x09\x00\x00\x00\x00\x00\x00\x00\x84\x00\x00\x00\x00\x00\x00\x00\x00\x26\x06\x00\x00\xb7\x01\x00\x00\xf7\xff\xff\xff\xff\xff\xff\xff\x84\x00\x00\x00\x00\x00\x00\x00\x00\x6f\x04\x00\x00\xb7\x01\x00\x00\x00", 2688);
*(uint64_t*)0x20000580 = 0xa80;
*(uint64_t*)0x20000588 = 0x50e6e0;
*(uint64_t*)0x20000590 = 0;
*(uint64_t*)0x20000598 = 0;
*(uint64_t*)0x200005a0 = 0x50f560;
*(uint64_t*)0x200005a8 = 0;
*(uint64_t*)0x200005b0 = 0;
*(uint64_t*)0x200005b8 = 0x50f720;
*(uint64_t*)0x200005c0 = 0;
*(uint64_t*)0x200005c8 = 0;
*(uint64_t*)0x200005d0 = 0x50f840;
*(uint64_t*)0x200005d8 = 0;
*(uint64_t*)0x200005e0 = 0;
*(uint64_t*)0x200005e8 = 0x50f8e0;
*(uint64_t*)0x200005f0 = 0;
*(uint64_t*)0x200005f8 = 0;
*(uint64_t*)0x20000600 = 0x50f9e0;
*(uint64_t*)0x20000608 = 0;
*(uint64_t*)0x20000610 = 0;
*(uint64_t*)0x20000618 = 0x50fb60;
*(uint64_t*)0x20000620 = 0;
*(uint64_t*)0x20000628 = 0;
*(uint64_t*)0x20000630 = 0x50fc80;
*(uint64_t*)0x20000638 = 0;
*(uint64_t*)0x20000640 = 0;
*(uint64_t*)0x20000648 = 0x50fd20;
*(uint64_t*)0x20000650 = 0;
*(uint64_t*)0x20000658 = 0;
*(uint64_t*)0x20000660 = 0x50fe40;
*(uint64_t*)0x20000668 = 0;
*(uint64_t*)0x20000670 = 0;
*(uint64_t*)0x20000678 = 0x50fee0;
*(uint64_t*)0x20000680 = 0x20015600;
memcpy((void*)0x20015600, "\x2a\x54\x14\xe9\x6a\xd0\xd1\x22\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x16\xbd\x86\xc7\x2e\x46\x03\xac\x63\x3e\xec\xde\xef\x69\x1d\x00\x00\x51\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x01\x17\x3f\xf6\x00\x45\x6e\x43\xf1\x86\x06\xe5\x72\x42\xf5\xf2\x62\x06\x00\x00\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xf9\x01\x00\x00\x00\x00\x00\x00\x00\x73\x0f\x00\x00\x28\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\xcc\x00\x00\x10\x00\x00\x00\x00\x00\x43\x0f\x00\x00\x30\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\xcc\x00\x00\x50\x00\x00\x00\x00\x00\x13\x0f\x00\x00\x30\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\xcc\x00\x00\x69\x00\x00\x00\x00\x00\xe3\x0e\x00\x00\x30\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 224);
*(uint64_t*)0x20000688 = 0xe0;
*(uint64_t*)0x20000690 = 0x510000;
*(uint64_t*)0x20000698 = 0x20015700;
memcpy((void*)0x20015700, "\x00\x00\x00\x00\x00\x00\x00\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x69\x00\x00\x00\x00\x00\x00\x00\x19\x00\x00\x00\x00\x00\x17\x3f\xf6\x00\x45\x6e\x43\xf1\x86\x06\xe5\x72\x42\xf5\xf2\x62\x03\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x50\x00\x00\x00\x00\x00\x00\x00\x19\x00\x00\x00\x00\x00\x17\x3f\xf6\x00\x45\x6e\x43\xf1\x86\x06\xe5\x72\x42\xf5\xf2\x62\x03\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x00\x40\x00\x00\x00\x00\x00\x17\x3f\xf6\x00\x45\x6e\x43\xf1\x86\x06\xe5\x72\x42\xf5\xf2\x62\x00\x00\x00\x00\x00\x00\x00\x00", 160);
*(uint64_t*)0x200006a0 = 0xa0;
*(uint64_t*)0x200006a8 = 0x510f40;
*(uint64_t*)0x200006b0 = 0;
*(uint64_t*)0x200006b8 = 0;
*(uint64_t*)0x200006c0 = 0x690000;
*(uint64_t*)0x200006c8 = 0;
*(uint64_t*)0x200006d0 = 0;
*(uint64_t*)0x200006d8 = 0x690480;
*(uint8_t*)0x20016800 = 0;
syz_mount_image(0x20000000, 0x20000100, 0x1000000, 0x34, 0x20000200, 0, 0x20016800);

}
int main(void)
{
		syscall(__NR_mmap, 0x1ffff000ul, 0x1000ul, 0ul, 0x32ul, -1, 0ul);
	syscall(__NR_mmap, 0x20000000ul, 0x1000000ul, 7ul, 0x32ul, -1, 0ul);
	syscall(__NR_mmap, 0x21000000ul, 0x1000ul, 0ul, 0x32ul, -1, 0ul);
			loop();
	return 0;
}
